"""
ISO 639-1 Language Codes
ISO 639-1 defines abbreviations for languages:
"""

Abkhazian = "ab"
Afar = "aa"
Afrikaans = "af"
Akan = "ak"
Albanian = "sq"
Amharic = "am"
Arabic = "ar"
Aragonese = "an"
Armenian = "hy"
Assamese = "as"
Avaric = "av"
Avestan = "ae"
Aymara = "ay"
Azerbaijani = "az"
Bambara = "bm"
Bashkir = "ba"
Basque = "eu"
Belarusian = "be"
Bengali_Bangla = "bn"
Bihari = "bh"
Bislama = "bi"
Bosnian = "bs"
Breton = "br"
Bulgarian = "bg"
Burmese = "my"
Catalan = "ca"
Chamorro = "ch"
Chechen = "ce"
Chichewa_Chewa_Nyanja = "ny"
Chinese = "zh"
Chinese_Simplified = "zh-Hans"
Chinese_Traditional = "zh-Hant"
Chuvash = "cv"
Cornish = "kw"
Corsican = "co"
Cree = "cr"
Croatian = "hr"
Czech = "cs"
Danish = "da"
Divehi_Dhivehi_Maldivian = "dv"
Dutch = "nl"
Dzongkha = "dz"
English = "en"
Esperanto = "eo"
Estonian = "et"
Ewe = "ee"
Faroese = "fo"
Fijian = "fj"
Finnish = "fi"
French = "fr"
Fula_Fulah_Pulaar_Pular = "ff"
Galician = "gl"
Gaelic_Scottish = "gd"
Gaelic_Manx = "gv"
Georgian = "ka"
German = "de"
Greek = "el"
Greenlandic = "kl"
Guarani = "gn"
Gujarati = "gu"
Haitian_Creole = "ht"
Hausa = "ha"
Hebrew = "he"
Herero = "hz"
Hindi = "hi"
Hiri_Motu = "ho"
Hungarian = "hu"
Icelandic = "is"
Ido = "io"
Igbo = "ig"
Indonesian = "id in"
Interlingua = "ia"
Interlingue = "ie"
Inuktitut = "iu"
Inupiak = "ik"
Irish = "ga"
Italian = "it"
Japanese = "ja"
Javanese = "jv"
Kalaallisut_Greenlandic = "kl"
Kannada = "kn"
Kanuri = "kr"
Kashmiri = "ks"
Kazakh = "kk"
Khmer = "km"
Kikuyu = "ki"
Kinyarwanda_Rwanda = "rw"
Kirundi = "rn"
Kyrgyz = "ky"
Komi = "kv"
Kongo = "kg"
Korean = "ko"
Kurdish = "ku"
Kwanyama = "kj"
Lao = "lo"
Latin = "la"
Latvian_Lettish = "lv"
Limburgish__Limburger = "li"
Lingala = "ln"
Lithuanian = "lt"
Luga_Katanga = "lu"
Luganda_Ganda = "lg"
Luxembourgish = "lb"
Manx = "gv"
Macedonian = "mk"
Malagasy = "mg"
Malay = "ms"
Malayalam = "ml"
Maltese = "mt"
Maori = "mi"
Marathi = "mr"
Marshallese = "mh"
Moldavian = "mo"
Mongolian = "mn"
Nauru = "na"
Navajo = "nv"
Ndonga = "ng"
Northern_Ndebele = "nd"
Nepali = "ne"
Norwegian = "no"
Norwegian_bokm = "nb"
Norwegian_nynorsk = "nn"
Nuosu = "ii"
Occitan = "oc"
Ojibwe = "oj"
Old_Church_Slavonic_Old_Bulgarian = "cu"
Oriya = "or"
Oromo_Afaan_Oromo = "om"
Ossetian = "os"
Pali = "pi"
Pashto_Pushto = "ps"
Persian = "fa"
Farsi = "fa"
Polish = "pl"
Portuguese = "pt"
Punjabi_Eastern = "pa"
Quechua = "qu"
Romansh = "rm"
Romanian = "ro"
Russian = "ru"
Sami = "se"
Samoan = "sm"
Sango = "sg"
Sanskrit = "sa"
Serbian = "sr"
Serbo_Croatian = "sh"
Sesotho = "st"
Setswana = "tn"
Shona = "sn"
Sichuan_Yi = "ii"
Sindhi = "sd"
Sinhalese = "si"
Siswati = "ss"
Slovak = "sk"
Slovenian = "sl"
Somali = "so"
Southern_Ndebele = "nr"
Spanish = "es"
Sundanese = "su"
Swahili_Kiswahili = "sw"
Swati = "ss"
Swedish = "sv"
Tagalog = "tl"
Tahitian = "ty"
Tajik = "tg"
Tamil = "ta"
Tatar = "tt"
Telugu = "te"
Thai = "th"
Tibetan = "bo"
Tigrinya = "ti"
Tonga = "to"
Tsonga = "ts"
Turkish = "tr"
Turkmen = "tk"
Twi = "tw"
Uyghur = "ug"
Ukrainian = "uk"
Urdu = "ur"
Uzbek = "uz"
Venda = "ve"
Vietnamese = "vi"
Volap = "vo"
Wallon = "wa"
Welsh = "cy"
Wolof = "wo"
Western_Frisian = "fy"
Xhosa = "xh"
Yiddish = "yi ji"
Yoruba = "yo"
Zhuang_Chuang = "za"
Zulu = "zu"
